@@ -37,6 +37,8 @@ DEFAULT_WHITE_CHANNEL_TYPE: Final = WhiteChannelType.WARM
 PRESET_MUSIC_MODE: Final = 0x62
 PRESET_MUSIC_MODE_LEGACY: Final = 0x5D
 
+PRESET_MUSIC_MODES: Final = {PRESET_MUSIC_MODE, PRESET_MUSIC_MODE_LEGACY}
+
 ATTR_IPADDR: Final = "ipaddr"
 ATTR_ID: Final = "id"
 ATTR_MODEL: Final = "model"
@@ -60,6 +62,7 @@ COLOR_MODE_ADDRESSABLE: Final = "ADDRESSABLE"
 
 STATE_CHANGE_LATENCY: Final = 1
 ADDRESSABLE_STATE_CHANGE_LATENCY: Final = 5
+PRESET_PATTERN_CHANGE_LATENCY: Final = 40  # Time to switch to music mode
 
 
 WRITE_ALL_COLORS = (LevelWriteMode.ALL, LevelWriteMode.COLORS)
