@@ -648,7 +648,7 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x04,
-        # AK001-ZJ100 == v3.09
+        # AK001-ZJ100 == v3.09, v3.15 (Illume)
         # AK001-ZJ200 == v5.20
         # There are a limited set of these devices that are the mini version but most are UFOs
         models=[
@@ -710,7 +710,7 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x08,
-        # AK001-ZJ2101 is v1
+        # AK001-ZJ2101 is v1.11
         # AK001-ZJ2145 is v2.11 (Upgradable to v2.15)
         models=["AK001-ZJ2101", "AK001-ZJ2145", "AK001-ZJ2147"],
         description="Controller RGB with MIC",
@@ -933,7 +933,7 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x33,
-        # 'AK001-ZJ100' == v3 - WIFI370 version
+        # 'AK001-ZJ100' == v3.03 - WIFI370 version
         # 'AK001-ZJ210' == v6.37 - Seen on the outdoor string lights from Lytworx
         # 'AK001-ZJ2104' == v7.07 - Seen on usb fairy lights - supports turning on by effect/levels set
         # 'AK001-ZJ2134' == v8.02 - seen on the water proof controllers for outdoor garden light
@@ -966,17 +966,18 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x35,
-        # 'AK001-ZJ2101' and 'AK001-ZJ2104' is v7
+        # 'AK001-ZJ2101' is v7.63 and 'AK001-ZJ2104' is v7
         # 'AK001-ZJ2145' is v8
-        # 'AK001-ZJ2146' is v9
+        # 'AK001-ZJ2146' is v9, 40w flood light, newer smart bulbs (with RF remote control support)
         # 'AK001-ZJ2147' is v9.7 (with RF remote control support)
-        # 'AK001-ZJ2146' 40w flood light, newer smart bulbs (with RF remote control support)
+        # 'AK001-ZJ21410' is v9.91 seen on the Bunpeon smart floor light ASIN:B09MN65324
         models=[
             "AK001-ZJ2101",
             "AK001-ZJ2104",
             "AK001-ZJ2145",
             "AK001-ZJ2146",
             "AK001-ZJ2147",
+            "AK001-ZJ21410",
         ],
         description="Bulb RGBCW",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
@@ -1011,10 +1012,14 @@ MODELS = [
         model_num=0x44,
         # v8 - AK001-ZJ200 aka old flux
         # v9 - AK001-ZJ210
-        models=["AK001-ZJ200", "AK001-ZJ210"],
+        # v10.49 - AK001-ZJ2101
+        models=["AK001-ZJ200", "AK001-ZJ210", "AK001-ZJ2101"],
         description="Bulb RGBW",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
-        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
+        protocols=[
+            MinVersionProtocol(10, PROTOCOL_LEDENET_8BYTE_AUTO_ON),
+            MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE),
+        ],
         mode_to_color_mode={},
         color_modes=COLOR_MODES_RGB_W,  # Formerly rgbwcapable
         channel_map={},
